@@ -18,13 +18,18 @@ matplotlib.rcParams['backend'] = 'GTK3Agg'
 matplotlib.rcParams['pcolor.shading'] = 'auto'
 matplotlib.rc('text', usetex=True)
 # matplotlib.rcParams['text.latex.preamble']=[r"\usepackage{amsmath}"]
-dpi = check_output("xdpyinfo | awk '/resolution/{print $2}'",shell=True).decode()
-dpi = np.array(dpi.strip().split('x'),dtype=int)
-screen_size = check_output("xrandr | grep \"*+\" | awk '{print $1}'",shell=True).decode().split('\n')
-#choose second monitor if present
-screen_size=screen_size[int(len(screen_size)>2)]
-screen_size = np.array(screen_size.split('x'),dtype=int)/dpi #inches
-
+try:
+    dpi = check_output("xdpyinfo | awk '/resolution/{print $2}'",shell=True).decode()
+    dpi = np.array(dpi.strip().split('x'),dtype=int)
+except:
+    dpi=96
+try:
+    screen_size = check_output("xrandr | grep \"*+\" | awk '{print $1}'",shell=True).decode().split('\n')
+    #choose second monitor if present
+    screen_size=screen_size[int(len(screen_size)>2)]
+    screen_size = np.array(screen_size.split('x'),dtype=int)/dpi #inches
+except:
+    screen_size=np.array([20.  , 11.25])
 
 ###########################################################################
 #def : plotting standard
